<?php

namespace InterludeSante\Statistics;

use InterludeSante\Statistics\Model;
use InterludeSante\Log;

class Chart
{
    /**
     * Retrieve chart by name action.
     * @access public
     *
     * @param string $name
     * @param int $index of chart
     * @param string $period
     * @param string $date
     *
     * @return array
     */
    public static function get(string $name, $index, string $period = 'week', string $date = '')
    {
        $chart = [];
        $userContext = $name === 'login' ? true : false;

        if ($name === 'survey') {
            $chart = self::getSurveyData($index);
        } else {
            $chart = self::getAddAction($name, switchFormatName('datetime', 'date'), $period, $date, $userContext);
        }


        return $chart;
    }

    /**
     * Retrieves actions data by establishment according to the given parameters.
     * @access public
     *
     * @param string $action_name
     * @param string $type
     * @param integer $etablishment_id
     * @param string $period
     *
     * @return array
     */
    private static function getAddAction(string $action_name, string $type, string $period, string $date, bool $userContext = false)
    {
        $actions = Model::getAction($action_name);
        $data = self::getActionsByPeriod($actions, $type, $period, $date, $userContext);

        return $data;
    }

    /**
     * Retrieves the actions according to the period and context.
     *
     * @param array $actions
     * @param string $type
     * @param string $period
     * @param boolean $userContext
     *
     * @return array
     */
    private static function getActionsByPeriod(array $actions, string $type, string $period, string $date, bool $userContext = false)
    {
        $date = self::getDate($date);
        $data = [];

        if ($period === 'month') {
            $by = 'months';
            $max_days = 12;
            $landmark = date('m', $date);
            $date = date('Y-m-d H:i:s', $date);

            $start = date('Y-m-01', strtotime($date . ' - ' . ($landmark - 1) . ' ' . $by));
            $data = self::getDataByPeriod($actions, $type, $by, $max_days, $start, $userContext);
        }

        if ($period === 'week') {
            $by = 'days';
            $max_days = 7;
            $landmark = date('w', $date);
            $date = date('Y-m-d', $date);

            $start = date('Y-m-d', strtotime($date . ' - ' . ($landmark - 1) . ' ' . $by));
            $data = self::getDataByPeriod($actions, $type, $by, $max_days, $start, $userContext);
        }

        return $data;
    }

    /**
     * Retrieves the data by period.
     *
     * @param array $actions
     * @param string $type
     * @param string $by
     * @param integer $max_days
     * @param string $start
     * @param boolean $userContext
     *
     * @return array
     */
    private static function getDataByPeriod(array $actions, string $type, string $by, int $max_days, string $start, bool $userContext)
    {
        for ($i = 0; $i < $max_days; $i++) {
            $total = [];

            $start_of_year = date('Y', strtotime($start));
            $start_of_month = date('n', strtotime($start));
            $start_of_day = date('j', strtotime($start));

            foreach ($actions as $action) {
                $year_registered = date('Y', strtotime($action[$type]));
                $month_registered = date('n', strtotime($action[$type]));
                $day_registered = date('j', strtotime($action[$type]));

                if ($by === 'days') {
                    if (($year_registered === $start_of_year) && ($month_registered === $start_of_month) && ($day_registered === $start_of_day)) {
                        if ($userContext) {
                            if (!in_array($action['user_id'], $total)) {
                                $total[] = $action['user_id'];
                            }
                        } else {
                            $total[] = $action['ID'];
                        }
                    }
                }

                if ($by === 'months') {
                    if (($year_registered === $start_of_year) && ($month_registered === $start_of_month)) {
                        if ($userContext) {
                            if (!in_array($action['user_id'], $total)) {
                                $total[] = $action['user_id'];
                            }
                        } else {
                            $total[] = $action['ID'];
                        }
                    }
                }
            }

            $data[$i]['label'] = $start;
            $data[$i]['total'] = count($total);

            if ($by === 'days') {
                $start = date('Y-m-d', strtotime($start . ' +1 days'));
            }

            if ($by === 'months') {
                $start = date('Y-m-01', strtotime($start . ' +1 months'));
            }
        }


        return $data;
    }

    /**
     * Retrieves the data by survey.
     *
     * @return array
     */
    private static function getSurveyData($index)
    {
        $surveys = Model::getAction('survey');
        $data = [];

        // Format survey data
        foreach ($surveys as $survey) {
            $data[$survey['sondage_id']]['title'] = html_entity_decode(get_the_title($survey['sondage_id']));
            $data[$survey['sondage_id']]['answers'][] = $survey['answer'];

            if (!empty($survey['answers'])) {
                $data[$survey['sondage_id']]['choices'] = array_map(function ($answer) {
                    return [
                    'answer' => array_values($answer)[0],
                    'total' => 0,
                    'percent' => 0
                ];
                }, json_decode($survey['answers'], true));
            }
        }

        // Sort DESC
        krsort($data);

        // Count answers
        $data = array_map(function ($survey, $index) {
            $survey['total'] = count($survey['answers']);
            $total_answers = array_count_values($survey['answers']);

            foreach ($total_answers as $answer => $count) {
                foreach ($survey['choices'] as $key => $choice) {
                    if ((string) $answer === (string) $choice['answer']) {
                        $survey['choices'][$key]['total'] = $count;
                        $survey['choices'][$key]['percent'] = ($count * 100) / $survey['total'];
                    }
                }
            }

            return $survey;
        }, $data, array_keys($data));

        $data[$index]['total_pie'] = count($data);

        return $data[$index];
    }

    /**
     * Retrieves the get parameter in timestamp format from the url.
     *
     * @return string
     */
    public static function getDate(string $new_date = '')
    {
        $date = !empty($_GET['date']) ? esc_html($_GET['date']) : time();

        if (!empty($new_date)) {
            return $new_date;
        }

        return $date;
    }
}
